summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/widgets/kmymoneyaccounttreeforecast.h')
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreeforecast.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/kmymoney2/widgets/kmymoneyaccounttreeforecast.h b/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
index 925d2e9..5f3cd85 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
+++ b/kmymoney2/widgets/kmymoneyaccounttreeforecast.h
@@ -21,8 +21,8 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qtimer.h>
-class QDragObject;
+#include <tqtimer.h>
+class TQDragObject;
// ----------------------------------------------------------------------------
// KDE Includes
@@ -39,8 +39,9 @@ class KMyMoneyAccountTreeForecastItem;
class KMyMoneyAccountTreeForecast : public KMyMoneyAccountTreeBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- KMyMoneyAccountTreeForecast(QWidget* parent = 0, const char *name = 0);
+ KMyMoneyAccountTreeForecast(TQWidget* tqparent = 0, const char *name = 0);
virtual ~KMyMoneyAccountTreeForecast() {}
void showSummary(MyMoneyForecast& forecast);
@@ -51,7 +52,7 @@ class KMyMoneyAccountTreeForecast : public KMyMoneyAccountTreeBase
void clearColumns(void);
public slots:
- void slotSelectObject(const QListViewItem* i);
+ void slotSelectObject(const TQListViewItem* i);
};
@@ -65,7 +66,7 @@ public:
* Constructor to be used to construct an account
* entry object for a forecast.
*
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
@@ -76,13 +77,13 @@ public:
* @param security const reference to the security used to show the value. Usually
* one should pass MyMoneyFile::baseCurrency() here.
*/
- KMyMoneyAccountTreeForecastItem(KMyMoneyAccountTreeForecastItem *parent, const MyMoneyAccount& account, const MyMoneyForecast& forecast, const QValueList<MyMoneyPrice>& price = QValueList<MyMoneyPrice>(), const MyMoneySecurity& security = MyMoneySecurity(), const EForecastViewType forecastViewType = eUndefined);
+ KMyMoneyAccountTreeForecastItem(KMyMoneyAccountTreeForecastItem *tqparent, const MyMoneyAccount& account, const MyMoneyForecast& forecast, const TQValueList<MyMoneyPrice>& price = TQValueList<MyMoneyPrice>(), const MyMoneySecurity& security = MyMoneySecurity(), const EForecastViewType forecastViewType = eUndefined);
/**
* Constructor to be used to construct an account
* entry object for a forecast.
*
* @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
@@ -93,7 +94,7 @@ public:
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeForecastItem(KListView *parent, const MyMoneyAccount& account, const MyMoneyForecast &forecast, const MyMoneySecurity& security = MyMoneySecurity(), const QString& name = QString());
+ KMyMoneyAccountTreeForecastItem(KListView *tqparent, const MyMoneyAccount& account, const MyMoneyForecast &forecast, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
~KMyMoneyAccountTreeForecastItem();
@@ -153,14 +154,14 @@ protected:
MyMoneyMoney balance() const;
void showAmount(int column, const MyMoneyMoney amount, const MyMoneySecurity security);
void adjustParentValue(int column, const MyMoneyMoney& value);
- void setValue(int column, MyMoneyMoney amount, QDate forecastDate);
+ void setValue(int column, MyMoneyMoney amount, TQDate forecastDate);
void setAmount(int column, MyMoneyMoney amount);
private:
MyMoneyForecast m_forecast;
int m_daysToBeginDay;
- QMap<int, MyMoneyMoney> m_values;
- QMap<int, MyMoneyMoney> m_amounts;
+ TQMap<int, MyMoneyMoney> m_values;
+ TQMap<int, MyMoneyMoney> m_amounts;
EForecastViewType m_forecastType;
};
@@ -65,7 +66,7 @@ public:
* entry object for a forecast.
*
- * @param parent pointer to the parent KAccountListView object this entry should be
+ * @param tqparent pointer to the tqparent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -76,13 +77,13 @@ public:
* entry object for a forecast.
*
- * @param parent pointer to the parent KAccountListView object this entry should be
+ * @param tqparent pointer to the tqparent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which